@@ -1,9 +1,10 @@
-from typing import ClassVar
+from typing import ClassVar, Union
 from typing import Any, Dict, List, Optional
 
 from vatis.asr_commons.config.headers import *
 
 from vatis.asr_commons.config.logging import get_logger
+from vatis.asr_commons.domain.transcriber import ConfigPacket, Base64InputPacket, PacketType
 from vatis.asr_commons.live.headers import *
 
 logger = get_logger(__name__)
@@ -33,6 +34,8 @@ class TranscriptionOptions:
     HOTWORDS: ClassVar[str] = 'hotwords'
     HOTWORDS_WEIGHT: ClassVar[str] = 'hotwords_weight'
 
+    COMMANDS_EXPRESSIONS: ClassVar[str] = 'commands_expression'
+
 
 def parse_post_processing_options(headers) -> Dict[str, Any]:
     post_processing_config: Dict[str, Any] = {}
@@ -126,3 +129,23 @@ def parse_hotwords_config(headers) -> Dict[str, Any]:
         hotwords_config[TranscriptionOptions.HOTWORDS_WEIGHT] = float(headers.get(HOTWORDS_WEIGHT_KEY))
 
     return hotwords_config
+
+
+def parse_formatting_config(headers) -> Dict[str, Any]:
+    config: Dict[str, Any] = {}
+
+    if COMMANDS_EXPRESSIONS_HEADER in headers:
+        config[TranscriptionOptions.COMMANDS_EXPRESSIONS] = headers[COMMANDS_EXPRESSIONS_HEADER]
+
+    return config
+
+
+def parse_input_packet(json_packet: dict) -> Union[Base64InputPacket, ConfigPacket]:
+    if json_packet.get('type') == PacketType.BASE64_INPUT:
+        return Base64InputPacket.from_json(json_packet)
+    elif json_packet.get('type') == PacketType.CONFIG:
+        return ConfigPacket.from_json(json_packet)
+    elif 'type' not in json_packet:  # backwards compatibility
+        return Base64InputPacket.from_json(json_packet)
+    else:
+        raise ValueError(f'Unsupported type: {json_packet.get("type")}')
