@@ -2,7 +2,7 @@ import sys
 
 from vatis.asr_commons.config import Language
 from vatis.asr_commons.custom_models.model import Model, ModelType
-from vatis.asr_commons.custom_models import ro_RO
+from vatis.asr_commons.custom_models import ro_RO, en_GB
 
 from pathlib import Path
 
@@ -10,6 +10,7 @@ __all__ = (
     'Model',
     'ModelType'
     'ro_RO',
+    'en_GB'
     'get_default',
     'compute_model_path'
 )
