@@ -20,12 +20,16 @@ BIT_DEPTH_HEADER: str = 'BitDepth'
 AUDIO_FORMAT_HEADER: str = 'AudioFormat'
 SENDING_HEADERS_HEADER: str = 'SendingHeaders'
 CHANNELS_HEADER: str = 'ChannelsHeader'
+# spoken formatting
+COMMAND_HEADER: str = 'SpokenCommand'
 
 # request headers ####################################################################################################
 FRAME_LEN_HEADER = 'FrameLength'
 FRAME_OVERLAP_HEADER = 'FrameOverlap'
 BUFFER_OFFSET_HEADER = 'BufferOffset'
 RESERVATION_KEY_HEADER = 'ReservationKey'
+# spoken formatting
+COMMANDS_EXPRESSIONS_HEADER = 'CommandsExpressions'
 
 # AMQP message headers ###############################################################################################
 USER_AMQP_HEADER: str = 'UserId'
